aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2020-04-23 15:02:13 +0000
committerMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2020-04-23 15:42:13 +0000
commitbbb2d33c938a34bc442c32eea063769c82209c3c (patch)
tree43798f348dd965399e88a0a2fb4e471e474ca030
parent6b4cadd7df44dcc8ebd0be252b759c3716492165 (diff)
tcwg-llvmbot: Rebalance bot CPU allocation
Prioritize quick and full bots. Change-Id: I18917de5552dbb5c317387067744c58a9d44c0f9
-rwxr-xr-xtcwg-base/tcwg-llvmbot/start.sh17
1 files changed, 9 insertions, 8 deletions
diff --git a/tcwg-base/tcwg-llvmbot/start.sh b/tcwg-base/tcwg-llvmbot/start.sh
index 4dcf08dc..f49fbafc 100755
--- a/tcwg-base/tcwg-llvmbot/start.sh
+++ b/tcwg-base/tcwg-llvmbot/start.sh
@@ -32,8 +32,6 @@ case "$slavename" in
linaro-armv8-01-aarch64-libcxx-noeh) ;;
linaro-armv8-01-aarch64-lld) ;;
linaro-armv8-01-aarch64-quick) ;;
- linaro-armv8-01-arm-full) ;;
- linaro-armv8-01-arm-full-selfhost) ;;
linaro-armv8-01-arm-global-isel) ;;
linaro-armv8-01-arm-libcxx) ;;
linaro-armv8-01-arm-libcxx-noeh) ;;
@@ -75,12 +73,15 @@ case "$buildmaster" in
*) hostname="$mastername-$slavename" ;;
esac
-# Set relative CPU weight of containers running silent bots to 1/20th of
-# normal containers. We want to run a full set of silent bots for
-# troubleshooting purposes, but don't want to waste a lot of CPU cycles.
-case "$mastername" in
- "silent") cpu_shares=50 ;;
- *) cpu_shares=1000 ;;
+# Set relative CPU weight of containers running
+# - quick bots to 10x usual priority
+# - full bots to 5x usual priority
+# - silent bots to 1/20th of usual priority
+case "$mastername:$slavename" in
+ normal:*-quick) cpu_shares=10000 ;;
+ normal:*-aarch64-full|*:*-arm-selfhost-neon) cpu_shares=5000 ;;
+ normal:*) cpu_shares=1000 ;;
+ *) cpu_shares=50 ;;
esac
mounts=""